/*******************************************************************************
 * Copyright 2013 Luca De Petrillo
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package com.example.testandroid.provider;

import com.lukasoft.android.voicecontrol.api.VoiceControlPluginApi;

import android.content.ContentProvider;
import android.content.ContentValues;
import android.database.Cursor;
import android.database.MatrixCursor;
import android.net.Uri;

public class CustomTypeProvider extends ContentProvider {

	@Override
	public int delete(Uri uri, String selection, String[] selectionArgs) {
		throw new IllegalArgumentException("This provider is read-only");
	}

	@Override
	public Uri insert(Uri uri, ContentValues values) {
		throw new IllegalArgumentException("This provider is read-only");
	}

	@Override
	public int update(Uri uri, ContentValues values, String selection, String[] selectionArgs) {
		throw new IllegalArgumentException("This provider is read-only");
	}

	@Override
	public boolean onCreate() {
		return true;
	}

	@Override
	public String getType(Uri uri) {
		return null;
	}

	@Override
	public Cursor query(Uri uri, String[] projection, String selection, String[] selectionArgs, String sortOrder) {
		// Check if someone is hacking Voice Control permission
		if (!VoiceControlPluginApi.isPermissionAuthentic(getContext(), VoiceControlPluginApi.PERMISSION_QUERY_TYPE)) {
			//throw new IllegalArgumentException("Permission hacked! Access denied!");
		}
		
		MatrixCursor matrixCursor = new MatrixCursor(new String[] {"ID_FIELD", "TEXT_FIELD"});
		
		// I'm italian, so I'm handling my language in order to check the sample :)
		if ("it".equalsIgnoreCase(getContext().getResources().getConfiguration().locale.getLanguage())) {
			matrixCursor.addRow(new Object[] {"ID_1", "valore 1"});
			matrixCursor.addRow(new Object[] {"ID_2", "valore 2"});
			matrixCursor.addRow(new Object[] {"ID_3", "valore 3"});
			matrixCursor.addRow(new Object[] {"ID_4", "valore 4"});
			matrixCursor.addRow(new Object[] {"ID_5", "valore 5"});
			
		} else {
			matrixCursor.addRow(new Object[] {"ID_1", "value 1"});
			matrixCursor.addRow(new Object[] {"ID_2", "value 2"});
			matrixCursor.addRow(new Object[] {"ID_3", "value 3"});
			matrixCursor.addRow(new Object[] {"ID_4", "value 4"});
			matrixCursor.addRow(new Object[] {"ID_5", "value 5"});
		}
		
		return matrixCursor;
	}
}
